Learn R Programming

EGRNi (version 0.1.6)

Edg2Fw: To compute F score from edge scores

Description

Edg2Fw computes the F-score from edge score using Fisher's weighted method. One pair of genes with k numbers of edge scores obtained from k numbers of independent method are combined using the probability value. The weight matrix w contains the weight for k number of methods.

Usage

Edg2Fw(s, w, k)

Value

Fw_sum matrix containing F score for significant gene pairs

Arguments

s

Matrix containing edge scores obtained from k numbers of methods with gene pairs in row and edge scores in column

w

Matrix containing weight for all individual methods

k

Numbers of independent methods considered for computing edge scores

Author

Chiranjib Sarkar(cschiranjib9@gmail.com)

Details

Edg2Fw function generates mixture distribution based on edge score for each method given column wise in s matrix. The probability value for each pair of gene obtained from mixture distribution are combined using Fisher's weighted method. The combined score Fw follows chi-square distribution with 2k degrees of freedom.

References

Sarkar, C., Parsad, R., Mishra, D.C. and Rai, A. (2020). An ensemble approach for gene regulatory network study in rice blast. Journal of Crop and Weed , 16 , 1-8.

Examples

Run this code
#load "EGRNi" library and Edge score data
library(EGRNi)
data(Edgescore)
data(weight)
Edg2Fw(Edgescore, weight, 4)

Run the code above in your browser using DataLab