Learn R Programming

EGRNi (version 0.1.6)

IntsctEdg2Fw: To compute F score for significant edges from individual methods

Description

IntsctEdg2Fw computes the Fw score using Fisher's weighted method for the significant edges obtained in k numbers of individual methods. The probability values are combined to compute the Fw score which follows chi-square distribution. The significant edges (>fdr) are selected using intersection.

Usage

IntsctEdg2Fw(s, w, k, fdr)

Value

Fw matrix containing F score for significant gene pairs

Arguments

s

Matrix containing edge scores obtained from k numbers of methods with gene pairs in row and edge scores in column

w

Matrix containing weight for all individual methods

k

Numbers of independent methods considered for computing edge scores

fdr

Cut-off for selecting significant edges

Author

Chiranjib Sarkar(cschiranjib9@gmail.com)

Details

IntsctEdg2Fw function generates mixture distribution based on edge score for each method given column wise in s matrix. The probability value for each pair of gene obtained from mixture distribution are combined using Fisher's weighted method. The combined score Fw follows chi-square distribution with 2k degrees of freedom.

References

Sarkar, C., Parsad, R., Mishra, D.C. and Rai, A. (2020). An ensemble approach for gene regulatory network study in rice blast. Journal of Crop and Weed , 16 , 1-8.

Examples

Run this code
#load "EGRNi" library and Edge score data
library(EGRNi)
data(Edgescore)
data(weight)
IntsctEdg2Fw(Edgescore,weight, k=4, fdr=0.1)

Run the code above in your browser using DataLab